==> 0.4.2&file=in_ffsox-2a-0.4.2-src.tar.gz: in_ffsox-2a-0.4.2/libpb/pb_load.c <==
#if ! defined (WIN32)
#include <dlfcn.h>
#endif
#include <stdlib.h>
#include "pb.h"

int pb_load(pb_str_t *dir, pb_str_t *pfx, pb_str_t *bn, pb_str_t *ver)
{
  pb_str_t *path;
#if defined (WIN32) // [
  int offs=_tcslen(dir->tcs)-1;
  HINSTANCE h;

  if (0==_tcscmp(_T("\\"),dir->tcs+offs)||0==_tcscmp(_T("/"),dir->tcs+offs)) {
    if (NULL==ver) {
      if (NULL==(path=pb_str_cat_ps(dir,bn,_PS(".dll"),NULL)))
        goto error;
    }
    else {
      if (NULL==(path=pb_str_cat_ps(dir,bn,_PS("-"),ver,_PS(".dll"),NULL)))
        goto error;
    }
  }
  else if (NULL==ver) {
    if (NULL==(path=pb_str_cat_ps(dir,PS_SEP,bn,_PS(".dll"),NULL)))
      goto error;
  }
  else {
    if (NULL==(path=pb_str_cat_ps(dir,PS_SEP,bn,_PS("-"),ver,
        _PS(".dll"),NULL))) {

      goto error;
    }
  }

  if (NULL==(h=LoadLibrary(PS_TCS(path)))) {
    _ftprintf(stderr,_T("Failed opening \"%s\": %d.\n"),PS_TCS(path),
        GetLastError());

    goto error;
  }
#else // ] [
  void *h;

  if (NULL==pfx&&NULL==ver) {
    if (NULL==(path=pb_str_cat_ps(dir,PS_SEP,bn,_PS(".so"),NULL)))
      goto error;
  }
  else if (NULL==ver) {
    if (NULL==(path=pb_str_cat_ps(dir,PS_SEP,pfx,bn,_PS(".so"),NULL)))
      goto error;
  }
  else if (NULL==pfx) {
    if (NULL==(path=pb_str_cat_ps(dir,PS_SEP,bn,_PS(".so."),ver,NULL)))
      goto error;
  }
  else if (NULL==(path=pb_str_cat_ps(dir,PS_SEP,pfx,bn,_PS(".so."),ver,NULL)))
    goto error;

  if (NULL==(h=dlopen(PS_UTF8(path),RTLD_LAZY))) {
    fprintf(stderr,"Failed opening \"%s\".\n",PS_UTF8(path));

    goto error;
  }
#endif // ]

	fprintf(stderr,"%s:%d \"%s\" loaded.\n",__func__,__LINE__,PS_OEM(path));
  free(path);

  return 0;
error:
  if (NULL!=path) {
		fprintf(stderr,"error loading \"%s\".",PS_OEM(path));
    free(path);
	}
	else
		fprintf(stderr,"error loading DLL.");

  return -1;
}

==> 0.6.0&file=in_ffsox-2a-0.6.0-src.tar.gz: in_ffsox-2a-0.6.0/libpb/pb_load.c <==
#if ! defined (WIN32)
#include <dlfcn.h>
#endif
#include <stdlib.h>
#include "pb.h"

int pb_load(pb_str_t *dir, pb_str_t *pfx, pb_str_t *bn, pb_str_t *ver)
{
  pb_str_t *path;
#if defined (WIN32) // [
  int offs=_tcslen(dir->tcs)-1;
  HINSTANCE h;

  if (0==_tcscmp(_T("\\"),dir->tcs+offs)||0==_tcscmp(_T("/"),dir->tcs+offs)) {
    if (NULL==ver) {
      if (NULL==(path=pb_str_cat_ps(dir,bn,_PS(".dll"),NULL)))
        goto error;
    }
    else {
      if (NULL==(path=pb_str_cat_ps(dir,bn,_PS("-"),ver,_PS(".dll"),NULL)))
        goto error;
    }
  }
  else if (NULL==ver) {
    if (NULL==(path=pb_str_cat_ps(dir,PS_SEP,bn,_PS(".dll"),NULL)))
      goto error;
  }
  else {
    if (NULL==(path=pb_str_cat_ps(dir,PS_SEP,bn,_PS("-"),ver,
        _PS(".dll"),NULL))) {

      goto error;
    }
  }

  if (NULL==(h=LoadLibrary(PS_TCS(path)))) {
    _ftprintf(stderr,_T("Failed opening \"%s\": %d.\n"),PS_TCS(path),
        GetLastError());

    goto error;
  }
#else // ] [
  void *h;

  if (NULL==pfx&&NULL==ver) {
    if (NULL==(path=pb_str_cat_ps(dir,PS_SEP,bn,_PS(".so"),NULL)))
      goto error;
  }
  else if (NULL==ver) {
    if (NULL==(path=pb_str_cat_ps(dir,PS_SEP,pfx,bn,_PS(".so"),NULL)))
      goto error;
  }
  else if (NULL==pfx) {
    if (NULL==(path=pb_str_cat_ps(dir,PS_SEP,bn,_PS(".so."),ver,NULL)))
      goto error;
  }
  else if (NULL==(path=pb_str_cat_ps(dir,PS_SEP,pfx,bn,_PS(".so."),ver,NULL)))
    goto error;

  if (NULL==(h=dlopen(PS_UTF8(path),RTLD_LAZY))) {
    //fprintf(stderr,"Failed opening \"%s\".\n",PS_UTF8(path));
    DVWRITELN("Failed opening \"%s\".",PS_UTF8(path));

    goto error;
  }
#endif // ]

	//fprintf(stderr,"%s:%d \"%s\" loaded.\n",__func__,__LINE__,PS_OEM(path));
	DVWRITELN("\"%s\" loaded.",PS_OEM(path));
  free(path);

  return 0;
error:
  if (NULL!=path) {
		//fprintf(stderr,"error loading \"%s\".",PS_OEM(path));
		DVWRITELN("error loading \"%s\".",PS_OEM(path));
    free(path);
	}
	else {
		//fprintf(stderr,"error loading DLL.");
		DVWRITELN("error loading DLL \"%s\".",PS_OEM(path));
  }

  return -1;
}
